<?php
// $Id: aurigma.admin.inc,v 1.2.2.1 2009/03/14 16:05:17 awolfey Exp $
/**
 * @file
 * The Aurigma admin settings form.
 *
 * The form provides control of the module as well as the Aurigma applet itself.
 */

function aurigma_admin_settings() {

  $form['module'] = array(
    '#type' => 'fieldset',
    '#weight' => $group_weight,
    '#title' => t('Module Settings'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );

  $form['module']['aurigma_node_types'] = array(
    '#type' => 'checkboxes',
    '#title' => t('Select content types that will use the Aurigma Uploader'),
    '#options' => node_get_types('names'),
    '#default_value' => variable_get('aurigma_node_types', array('')),
    '#description' => t('The uploader will only be available for multiple imagefields on these content types.'),
  );

  $form['module']['aurigma_field_types'] = array(
    '#type' => 'checkboxes',
    '#title' => t('Select imagefield fields that will use the Aurigma Uploader'),
    '#options' => aurigma_fieldlist(),
    '#default_value' => variable_get('aurigma_field_types', array('')),
    '#description' => t('The uploader will only be available for multiple imagefields with these field names.
                         You must also add the field to your content type. If no fields are listed you will
                         need to create one before you can use the uploader.'),
  );

  $form['applet'] = array(
    '#type' => 'fieldset',
    '#weight' => $group_weight,
    '#title' => t('Applet Settings'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );

  $form['applet']['aurigma_licensekey'] = array(
    '#type' => 'textfield',
    '#size' => '80',
    '#title' => t('Enter your Aurigma Uploader license key:'),
    '#default_value' => variable_get('aurigma_licensekey', ''),
    '#description' => t("You must have a valid key to use the uploader"),
    '#required' => FALSE,
  );

  $form['applet']['aurigma_applet_width'] = array(
    '#type' => 'textfield',
    '#size' => '4',
    '#title' => t('Applet width'),
    '#default_value' => variable_get('aurigma_applet_width', '650'),
    '#description' => t("The width of the embedded applet."),
    '#required' => FALSE,
  );

  $form['applet']['aurigma_applet_height'] = array(
    '#type' => 'textfield',
    '#size' => '4',
    '#title' => t('Applet height'),
    '#default_value' => variable_get('aurigma_applet_height', '400'),
    '#description' => t("The height of the embedded applet."),
    '#required' => FALSE,
  );

  $form['applet']['aurigma_maxfilesize'] = array(
    '#type' => 'textfield',
    '#size' => '10',
    '#title' => t('Maximum individual file size in megabytes'),
    '#default_value' => variable_get('aurigma_maxfilesize', 0),
    '#description' => t("For no limit, set to 0."),
    '#required' => FALSE,
  );

  $form['applet']['aurigma_maxtotalsize'] = array(
    '#type' => 'textfield',
    '#size' => '15',
    '#title' => t('Maximum batch upload size in megabytes'),
    '#default_value' => variable_get('aurigma_maxtotalsize', 0),
    '#description' => t("For no limit, set to 0."),
    '#required' => FALSE,
  );

  $form['applet']['aurigma_maxfilecount'] = array(
    '#type' => 'textfield',
    '#size' => '3',
    '#title' => t('Maximum number of files in an upload batch'),
    '#default_value' => variable_get('aurigma_maxfilecount', 0),
    '#description' => t("For no limit, set to 0."),
    '#required' => FALSE,
  );

  $form['applet']['aurigma_rotate'] = array(
    '#type' => 'radios',
    '#title' => t('Allow users to rotate images before uploading?'),
    '#options' => array(
      'TRUE' => t('Allow image rotation'),
      'FALSE' => t('Don\'t allow rotation'),
    ),
    '#default_value' => variable_get('aurigma_rotate', 'true')
  );

  $form['applet']['aurigma_params'] = array(
    '#type' => 'textarea',
    '#title' => t('Enter additional Aurigma parameters here.'),
    '#default_value' => variable_get('aurigma_params', ''),
    '#description' => t("Use this format with no spaces: parameter=value. Put each parameter on a separate line.
                        For example:
<pre>
                        BackgroundColor=#333
                        FolderPaneBackgroundColor=#000
</pre>
                        CAUTION: Incorrect parameter style may cause your uploader or content type to no longer display."),
    '#required' => FALSE,
  );
  return system_settings_form($form);
}

/* Generate a list of suitable fields
 */
function aurigma_fieldlist() {
  $fields = (content_fields());
  foreach ($fields as $field) {
    if (($field['module'] == 'imagefield' || $field['module'] == 'filefield') && $field['active'] && $field['multiple']) {
      $fieldlist[$field['field_name']] = $field['field_name'];
    }
  }
  return $fieldlist;
}